==> latte-dock_0.9.9.orig.tar.xz: latte-dock-0.9.9/plasmoid/metadata.desktop.cmake <==
[Desktop Entry]
Name=Latte Tasks
Name[ca]=Tasques del Latte
Name[ca@valencia]=Tasques del Latte
Name[cs]=Úlohy Latte
Name[en_GB]=Latte Tasks
Name[es]=Tareas de Latte
Name[eu]=Latte atazak
Name[fi]=Latte-tehtävät
Name[gl]=Tarefas de Latte
Name[id]=Tugas-tugas Latte
Name[it]=Processi di Latte
Name[ko]=Latte 태스크
Name[nl]=Latte-taken
Name[nn]=Latte-oppgåver
Name[pl]=Zadania Latte
Name[pt]=Tarefas do Latte
Name[pt_BR]=Tarefas do Latte
Name[ru]=Процессы Latte
Name[sk]=Úlohy Latte
Name[sv]=Latte aktiviteter
Name[uk]=Завдання Латте
Name[x-test]=xxLatte Tasksxx
Name[zh_CN]=Latte 任务管理器
Name[zh_TW]=Latte 工作
Comment=Tasks plasmoid from Latte Dock
Comment[ca]=Plasmoide de tasques del Latte Dock
Comment[ca@valencia]=Plasmoide de tasques del Latte Dock
Comment[cs]=Plasmoid úloh z doku Latte
Comment[en_GB]=Tasks plasmoid from Latte Dock
Comment[es]=Plasmoide de tareas de Latte Dock
Comment[eu]=Atazen plasmoidea Latte Docketik
Comment[fi]=Latte-telakan tehtäväsovelma
Comment[gl]=Plasmoides de tarefas da doca Latte
Comment[id]=Plasmoid tugas-tugas dari Dock Latte
Comment[it]=Plasmoide dei processi da Latte Dock
Comment[ko]=Latte 도구집의 태스크 Plasmoid
Comment[nl]=Plasmoid voor taken uit Latte Dock
Comment[nn]=Oppgåve-skjermelement frå Latte-dokk
Comment[pl]=Plazmoidy zadań dla doku Latte
Comment[pt]=Plasmóide de tarefas da Área Acoplável do Latte
Comment[pt_BR]=Plasmoide de tarefas do Latte Dock
Comment[ru]=Виджет процессов из Latte Dock
Comment[sk]=Plazmoid úloh z doku Latte
Comment[sv]=Aktivitetsplasmoid för Latte dockningsfönster
Comment[uk]=Плазмоїд завдань з панелі Латте
Comment[x-test]=xxTasks plasmoid from Latte Dockxx
Comment[zh_CN]=Latte 停靠栏的任务管理 Plasma 部件
Comment[zh_TW]=來自 Latte Dock 的工作 Plasmoid

Type=Service
Icon=latte-dock
X-KDE-ServiceTypes=Plasma/Applet
X-Plasma-API=declarativeappletscript
X-Plasma-MainScript=ui/main.qml
X-Plasma-Provides=org.kde.plasma.multitasking
X-KDE-PluginInfo-Author=@AUTHOR@
X-KDE-PluginInfo-Email=@EMAIL@
X-KDE-PluginInfo-Name=org.kde.latte.plasmoid
X-KDE-PluginInfo-Version=@VERSION@
X-KDE-PluginInfo-Website=@WEBSITE@
X-KDE-PluginInfo-Category=Windows and Tasks
X-KDE-PluginInfo-License=GPL v2+
X-KDE-PluginInfo-EnabledByDefault=true

==> latte-dock_0.9.11.orig.tar.xz: latte-dock-0.9.11/plasmoid/metadata.desktop.cmake <==
[Desktop Entry]
Name=Latte Tasks
Name[ca]=Tasques del Latte
Name[ca@valencia]=Tasques del Latte
Name[cs]=Úlohy Latte
Name[en_GB]=Latte Tasks
Name[es]=Tareas de Latte
Name[eu]=Latte atazak
Name[fi]=Latte-tehtävät
Name[gl]=Tarefas de Latte
Name[id]=Tugas-tugas Latte
Name[it]=Processi di Latte
Name[ko]=Latte 태스크
Name[nl]=Latte-taken
Name[nn]=Latte-oppgåver
Name[pl]=Zadania Latte
Name[pt]=Tarefas do Latte
Name[pt_BR]=Tarefas do Latte
Name[ru]=Процессы Latte
Name[sk]=Úlohy pre Latte
Name[sv]=Latte aktiviteter
Name[uk]=Завдання Латте
Name[x-test]=xxLatte Tasksxx
Name[zh_CN]=Latte 任务管理器
Name[zh_TW]=Latte 工作
Comment=Tasks plasmoid from Latte Dock
Comment[ca]=Plasmoide de tasques del Latte Dock
Comment[ca@valencia]=Plasmoide de tasques del Latte Dock
Comment[cs]=Plasmoid úloh z doku Latte
Comment[en_GB]=Tasks plasmoid from Latte Dock
Comment[es]=Plasmoide de tareas de Latte Dock
Comment[eu]=Atazen plasmoidea Latte Docketik
Comment[fi]=Latte-telakan tehtäväsovelma
Comment[gl]=Plasmoides de tarefas da doca Latte
Comment[id]=Plasmoid tugas-tugas dari Dock Latte
Comment[it]=Plasmoide dei processi da Latte Dock
Comment[ko]=Latte 도구집의 태스크 Plasmoid
Comment[nl]=Plasmoid voor taken uit Latte Dock
Comment[nn]=Oppgåve-skjermelement frå Latte-dokk
Comment[pl]=Plazmoidy zadań dla doku Latte
Comment[pt]=Plasmóide de tarefas da Área Acoplável do Latte
Comment[pt_BR]=Plasmoide de tarefas do Latte Dock
Comment[ru]=Виджет процессов из Latte Dock
Comment[sk]=Plazmoid úloh z doku Latte
Comment[sv]=Aktivitetsplasmoid för Latte dockningsfönster
Comment[uk]=Плазмоїд завдань з панелі Латте
Comment[x-test]=xxTasks plasmoid from Latte Dockxx
Comment[zh_CN]=Latte 停靠栏的任务管理 Plasma 部件
Comment[zh_TW]=來自 Latte Dock 的工作 Plasmoid

Type=Service
Icon=latte-dock
X-KDE-ServiceTypes=Plasma/Applet
X-Plasma-API=declarativeappletscript
X-Plasma-MainScript=ui/main.qml
X-Plasma-Provides=org.kde.plasma.multitasking
X-KDE-PluginInfo-Author=@AUTHOR@
X-KDE-PluginInfo-Email=@EMAIL@
X-KDE-PluginInfo-Name=org.kde.latte.plasmoid
X-KDE-PluginInfo-Version=@VERSION@
X-KDE-PluginInfo-Website=@WEBSITE@
X-KDE-PluginInfo-Category=Windows and Tasks
X-KDE-PluginInfo-License=GPL v2+
X-KDE-PluginInfo-EnabledByDefault=true
